<?php
defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'WCGW_Admin_Notices' ) ) :

    class WCGW_Admin_Notices {
    
        private static $outdated_files = array();

        /**
         * Constructor
        */
        public function __construct() {

            if ( ! current_user_can( 'manage_woocommerce' ) ) return;
            
            // Help cure open source burnout!
            add_action( 'admin_notices',    array( $this, 'help_a_girl_out_notice' ) );
            // Alert for folks who haven't set up a wrap category
            add_action( 'admin_notices',    array( $this, 'setup_error_notice' ) );
            // Alert for folks with outdated template files
            add_action( 'admin_notices',    array( $this, 'template_file_check_notice' ) );
            // Ajax dismiss "help a girl out" notice
            add_action( 'wp_ajax_wcgwp_dismiss_notice',     array( $this, 'dismiss_notice' ) );


        }
        
        /**
         * Maybe bother users with important information
         *
         * @return void
        */
        public function help_a_girl_out_notice() {
    
            $screen = get_current_screen();
            if ( $screen->id !== 'woocommerce_page_wc-settings' && $screen->id !== 'woocommerce_page_wc-status'  ) return;
        
            if ( defined( 'DISABLE_NAG_NOTICES' ) && 'DISABLE_NAG_NOTICES' === TRUE ) return;

            wp_enqueue_script('jquery');
            $dismiss = get_option( 'wcgwp_donate_dismiss_03-21' );

            if ( ( isset( $_GET['section'] ) && $_GET['section'] === 'wcgiftwrapper' ) && empty( $dismiss ) ) { ?>
                <div class="updated settings-error notice is-dismissible wcgwp-donation">
                    <p style="font-size: 1.15em;">
                        If you find this plugin useful, and particularly if you benefit from it, please take a moment to write <a href="https://wordpress.org/support/plugin/woocommerce-gift-wrapper/reviews/?filter=5" target="_blank" rel="noopener">an encouraging review</a>, donate a donut (YUM!) using the button below, or maybe even <a href="https://web.little-package.com/downloads/woocommerce-gift-wrapper" target="_blank" rel="noopener">upgrade to the premium version from Little Package for more features and prioritized email support</a>.</p>
                        <p style="font-size: 1.15em;">Your enthusiasm makes donating my time to this open-source project worthwhile.<br />
                    </p>
                    <script type="text/javascript" src="https://cdnjs.buymeacoffee.com/1.0.0/button.prod.min.js" data-name="bmc-button" data-slug="littlepackage" data-color="#eee2be" data-emoji="🍩" data-font="Cookie" data-text="Buy me a donut!" data-outline-color="#000000" data-font-color="#530303" data-coffee-color="#FFDD00" ></script>
                    <button style="z-index: 100;" data-security="<?php echo wp_create_nonce('wcgwp-donate-03-21'); ?>" type="button" class="notice-dismiss wcgwp-donation-dismiss">
                        <span class="screen-reader-text">Dismiss this notice.</span>
                    </button>
                    <p>If you have questions about the free version of WooCommerce Gift Wrapper, please <a href="https://wordpress.org/support/plugin/woocommerce-gift-wrapper/" target="_blank" rel="noopener nofollow">open a topic at wordpress.org</a> after first searching the forum to make sure your question hasn't already been answered. I respond to inquiries about the free version of Gift Wrapper as a volunteer in my spare time. Please be patient.</p>

                </div>
                <script>
                jQuery(document).ready(function($){
                    $('.wcgwp-donation .wcgwp-donation-dismiss').on('click', function() {
                        const $this = $(this);
                        const args = {action: 'wcgwp_dismiss_notice',security: $this.data('security')};
                        $.post(ajaxurl, args, function(){$this.parent().slideUp();});
                    });
                });</script>
            <?php }
    
        }      
        
        /**
         * AJAX-called fx to delete nag
         *
         * @return void
        */
        public function dismiss_notice() {

            check_admin_referer( 'wcgwp-donate-03-21', 'security' );
            delete_option( 'wcgwp_donate_dismiss_11-16' );
            update_option( 'wcgwp_donate_dismiss_03-21', true, false );

        }
    
        /**
         * Provide user with heads up if gift wrap category is not set
         *
         * @return void
        */        
        public function setup_error_notice() {
        
            $screen = get_current_screen();
            if ( $screen->id !== 'woocommerce_page_wc-settings' && $screen->id !== 'woocommerce_page_wc-status'  ) return;
        
            $giftwrap_cat_id = get_option( 'wcgwp_category_id' );
            $display = get_option( 'wcgwp_display' );

            // Admin doesn't have a gift wrap category set!
            if ( $giftwrap_cat_id == 'none' && ! in_array( 'none', $display ) ) { ?>
                    <div id="message" class="notice notice-error is-dismissible">
                        <p><?php printf( wp_kses( __( 'WooCommerce Gift Wrapper is not set up properly. Please choose a category to represent your gift wrap options <a href="%s">in the settings</a>.', 'woocommerce-gift-wrapper' ), array( 'a' => array( 'href' => array() ) ), admin_url( 'admin.php?page=wc-settings&tab=products&section=wcgiftwrapper' ) ) ); ?></p>
                    </div>  
            <?php }
    
        }

        /**
         * If WC admin page, send core templates to check_template_outdated() method 
         * for version-checking
         * 
         * @return void
        */
        public static function template_file_check_notice() {
        
            $screen = get_current_screen();
            if ( $screen->id !== 'woocommerce_page_wc-settings' && $screen->id !== 'woocommerce_page_wc-status' ) return;
            $core_templates = WC_Admin_Status::scan_template_files( WCGW_PLUGIN_DIR . '/templates' );
            $outdated = self::check_template_outdated( $core_templates );
            if ( $outdated ) {
                wcgwp_outdated_template_notice( self::$outdated_files );
            }

        }

        /**
         * Compare plugin template files with any user overrides, 
         * looking for outdated versions in order to warn user
         *
         * @param array $files
         * @return boolean|void
        */

        public static function check_template_outdated( $files ) {

            $outdated       = FALSE;
            $theme_file     = FALSE;
            if ( empty( $files ) ) {
                return $outdated;           
            } else if ( ! is_array( $files ) ) {
                $files = (array) $files;
            }
                        
            foreach ( $files as $file ) {
            
                if ( file_exists( get_stylesheet_directory() . '/' . WC()->template_path() . $file ) ) {
                    $theme_file = get_stylesheet_directory() . '/' . WC()->template_path() . $file;
                } elseif ( file_exists( get_template_directory() . '/' . WC()->template_path() . $file ) ) {
                    $theme_file = get_template_directory() . '/' . WC()->template_path() . $file;
                }

                if ( FALSE !== $theme_file ) {
                    $core_version  = WC_Admin_Status::get_file_version( WCGW_PLUGIN_DIR . '/templates/' . $file );
                    $theme_version = WC_Admin_Status::get_file_version( $theme_file );

                    if ( $core_version && $theme_version && version_compare( $theme_version, $core_version, '<' ) ) {
                        $outdated = TRUE;
                        if ( ! in_array( $theme_file, self::$outdated_files ) ) {
                            self::$outdated_files[] = $theme_file;
                        }
                    }
                }

            }         
         
            return $outdated;
            
        }
        
    }        
  
endif;

/**
 * Provide user with heads up if template has been updated
 *
 * @param array $outdated_files
 * @return void
*/           
function wcgwp_outdated_template_notice( $outdated_files ) {

    if ( defined( 'DISABLE_NAG_NOTICES' ) && 'DISABLE_NAG_NOTICES' === TRUE ) return;

    $theme = wp_get_theme();
    ?>
    <div id="message" class="updated woocommerce-message notice notice-error is-dismissible">
        <p>
            <?php /* translators: %s: theme name */ ?>
            <strong><?php printf( wp_kses( __( 'Your theme (%s) contains outdated copies of some WooCommerce Gift Wrapper template files.' , 'woocommerce-gift-wrapper' ), array( 'a' => array( 'href' => array() ) ), esc_html( $theme['Name'] ) ) ); ?></strong><br />
            <?php esc_html_e( 'The following files should be updated to reflect parent template file changes to ensure they are secure and compatible with the current version of Gift Wrapper.', 'woocommerce-gift-wrapper' ); ?>  
            <ol>
            <?php foreach ( $outdated_files as $file ) { ?>
                <li><?php echo $file; ?></li>
            <?php } ?>
            </ol>
            <?php esc_html_e( 'If you copied over a template file to your theme to change something, you will need to copy the new version of the template and apply your changes again.', 'woocommerce-gift-wrapper' ); ?>

        </p>

    </div>

<?php }       
