<?php defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'WCGW_Settings' ) ) :

class WCGW_Settings {

	/**
     * Constructor
     *
    */
    public function __construct() {
    
        // settings link on the plugins listing page
    	add_filter( 'plugin_action_links_' . WCGW_PLUGIN_BASE_FILE,     array( $this, 'plugin_action_links' ), 10, 1 );
    	
        // Add section under Woocommerce->Settings->Products
    	add_filter( 'woocommerce_get_sections_products',                array( $this, 'add_section' ), 10, 1 );
    	
    	// Add settings to the section we created with add_section()
		add_filter( 'woocommerce_get_settings_products',                array( $this, 'add_settings' ), 10, 2);
	
    }
    
	/**
     * Add settings link to WP plugin listing
	 *
	 * @param array $links
     * @return array
    */
	public function plugin_action_links( $links ) {
		    
        $wcgwp_links = array(
                sprintf( '<a href="%s" target="_blank" rel="noopener">%s</a>', 'https://www.paypal.me/littlepackage', esc_html__( 'Donate', 'woocommerce-gift-wrapper' ) ),
                sprintf( '<a href="%s">%s</a>', admin_url( 'admin.php?page=wc-settings&tab=products&section=wcgiftwrapper' ), esc_html__( 'Settings', 'woocommerce-gift-wrapper' ) ),
        );
        return array_merge( $wcgwp_links, $links );

	}

 	/**
     * Add settings section under Woocommerce->Settings->Products
     *
     * @param array $sections
     * @return array
    */
    public function add_section( $sections ) {
    
		$sections['wcgiftwrapper'] = __( 'Gift Wrapping', 'woocommerce-gift-wrapper' );
		return $sections;

	}

    /**
     * Get array of WooCommerce product categories
     *
     * @return array
    */
    public static function woocommerce_product_cats() {

        $giftwrap_cat_id = get_option( 'wcgwp_category_id', '' );	
        // Check if category is translated with WPML
        $wpml_category = apply_filters( 'wpml_object_id', $giftwrap_cat_id, 'product_cat', true );
        if ( $giftwrap_cat_id != $wpml_category ) {
            update_option( 'wcgwp_category_id', $wpml_category );
        }

        $selection = array();
        $args = array(
            'orderby' 			=> 'id',
            'order' 			=> 'ASC',
            'taxonomy' 			=> 'product_cat',
            'hide_empty' 		=> '0',
            'hierarchical' 		=> '1'
        );
        
        $cats = get_categories( $args );
        $cats = isset( $cats ) ? $cats : array();
    
        if ( ! empty( $cats ) ) {
            $selection['none'] = __( 'None selected', 'woocommerce-gift-wrapper' );
            foreach ( $cats as $cat ) {
                $selection[ $cat->term_id ] = $cat->name;
            }
        } else {
            $selection['none'] = __( 'None set up yet', 'woocommerce-gift-wrapper' );
        }

        return $selection;

    }	        
            
	/**
	 * Add settings to the section we created with add_section()
	 *
	 * @param array $settings
	 * @param string $current_section
	 * @return array
    */
	public function add_settings( $settings, $current_section ) {

 		if ( $current_section == 'wcgiftwrapper' ) { 
 		
 		    // Clear array - don't add existing settings array to our super fresh tab
            $settings = array();

            $settings[] = array( 
                'name' 				=> __( 'Basic Setup Instructions', 'woocommerce-gift-wrapper' ), 
                'type' 				=> 'title', 
                'desc' 				=> '<strong>1.</strong> ' 
                					. sprintf( wp_kses( __( 'Start by <a href="%s" target="_blank">adding at least one WooCommerce product</a> called "Gift Wrapping" or something similar. It can be hidden from the catalog if you like.', 'woocommerce-gift-wrapper' ), array( 'a' => array( 'href' => array() ) ) ), admin_url( 'post-new.php?post_type=product' ) ) 
                					. '<br /><strong>2.</strong> ' . __( 'Create a unique WooCommerce product category for this/these gift wrapping product(s), and add them to this category.', 'woocommerce-gift-wrapper' ) 
                					. '<br /><strong>3.</strong> ' . __( 'Then consider the options below.', 'woocommerce-gift-wrapper' ),
            );
            
            $settings[] = array( 
                'name' 				=> __( 'General Gift Wrapping Options', 'woocommerce-gift-wrapper' ), 
                'type' 				=> 'title', 
            );

            $settings[]	= array(
                'id'				=> 'wcgwp_category_id',
                'title'           	=> __( 'Gift Wrap Category', 'woocommerce-gift-wrapper' ),
                'desc_tip'			=> __( 'Define the category which holds your gift wrap product(s).', 'woocommerce-gift-wrapper' ),
                'type'            	=> 'select',
                'default'         	=> 'none',
                'options'         	=> self::woocommerce_product_cats(),
                'class'           	=> 'chosen_select',				
                'custom_attributes'	=> array(
                    'data-placeholder'  => __( 'Define a Category', 'woocommerce-gift-wrapper' )
                ),
                'autoload'          => false,
            );
            
            $settings[] = array(
                'id'       			=> 'wcgwp_details',
                'name'     			=> __( 'Gift Wrap Details', 'woocommerce-gift-wrapper' ),
                'desc_tip' 			=> __( 'Optional text to give any details or conditions of your gift wrap offering. This text is not translatable by Wordpress i18n, but can be translated by WPML. Leave this field empty to translate via another means. Hide this field with CSS, or by purchasing the paid version of the plugin and setting this to zero.', 'woocommerce-gift-wrapper' ),
                'type'     			=> 'textarea',
                'default'         	=> '',
                'custom_attributes'	=> array(
                    'rows'  => 4
                ),
                'autoload'          => false,
            );
            
            $settings[] = array(
                'id'       			=> 'wcgwp_textarea_limit',
                'name'     			=> __( 'Textarea Character Limit', 'woocommerce-gift-wrapper' ),
                'desc_tip' 			=> __( 'How many characters your customer can type when creating their own note for giftwrapping. Defaults to 1000 characters; lower this number if you want shorter notes from your customers.', 'woocommerce-gift-wrapper' ),
                'type'     			=> 'number',
                'default'         	=> '1000',
                'autoload'          => false,
            );
            
            $settings[] = array(
                    'type' => 'sectionend',
                ); 
            $settings[] = array( 
                'name' 				=> __( 'Cart/Checkout Gift Wrapping Options', 'woocommerce-gift-wrapper' ), 
                'type' 				=> 'title', 
                'desc' 				=> __( 'These settings apply to per-order wrap options in the cart and checkout areas, not line item (per-item) or per-product wrapping.', 'woocommerce-gift-wrapper' ) 
                						. '<br />' . sprintf( wp_kses( __( '<a href="%s" rel="noopener" target="_blank">Per-product and line item gift wrapping options are available in the PLUS version of this plugin</a>', 'woocommerce-gift-wrapper' ), array( 'a' => array( 'href' => array() ) ) ), 'https://web.little-package.com/downloads/woocommerce-gift-wrapper-plus/' ),

            );
                $settings[] = array(
                    'id'       			=> 'wcgwp_display',
                    'name'     			=> __( 'Where to Show Gift Wrapping', 'woocommerce-gift-wrapper' ),
                    'desc_tip' 			=> __( 'Choose where to show gift wrap options to the customer on the cart page. You may choose more than one.', 'woocommerce-gift-wrapper' ),
                    'type'     			=> 'multiselect',
                    'default'         	=> 'none',
                    'options'     		=> array(
                        'before_cart'       => __( 'Before cart', 'woocommerce-gift-wrapper' ),
                        'after_coupon'      => __( 'Before cart collaterals', 'woocommerce-gift-wrapper' ),
                        'after_cart'		=> __( 'After cart', 'woocommerce-gift-wrapper' ),
                        'before_checkout'	=> __( 'Before checkout', 'woocommerce-gift-wrapper' ),
                        'after_checkout'	=> __( 'After checkout', 'woocommerce-gift-wrapper' ),
                        'none'	            => __( 'None', 'woocommerce-gift-wrapper' ),
                    ),
                    'css'      			=> 'min-height:110px',
                    'autoload'          => false,
                );
                $settings[] = array(
                    'id'       			=> 'wcgwp_modal',
                    'name'     			=> __( 'Should options open in pop-up?', 'woocommerce-gift-wrapper' ),
                    'desc_tip' 			=> __( 'If checked, there will be a link ("header") in the cart, which when clicked will open a window for customers to choose gift wrapping options. It can be styled and might be a nicer option for your site.', 'woocommerce-gift-wrapper' ),
                    'type'     			=> 'select',
                    'default'         	=> 'yes',
                    'options'     		=> array(
                        'yes'				=> __( 'Modal/Popup', 'woocommerce-gift-wrapper' ),
                        'no'				=> __( 'jQuery SlideToggle', 'woocommerce-gift-wrapper' ),
                    ),
                    'autoload'          => false,
                );
                $settings[] = array(
                    'id'       			=> 'wcgwp_show_thumb',
                    'name'     			=> __( 'Show Gift Wrap Thumbs in Cart', 'woocommerce-gift-wrapper' ),
                    'desc_tip' 			=> __( 'Should gift wrap product thumbnail images be visible in the cart?', 'woocommerce-gift-wrapper' ),
                    'type'     			=> 'select',
                    'default'         	=> 'yes',
                    'options'     		=> array(
                        'yes'	=> __( 'Yes', 'woocommerce-gift-wrapper' ),
                        'no'	=> __( 'No', 'woocommerce-gift-wrapper' ),
                    ),
                    'autoload'          => false,
                );
                $settings[] = array(
                    'id'       			=> 'wcgwp_link',
                    'name'     			=> __( 'Link thumbnails?', 'woocommerce-gift-wrapper' ),
                    'desc_tip' 			=> __( 'Should thumbnail images link to gift wrap product details?', 'woocommerce-gift-wrapper' ),
                    'type'     			=> 'select',
                    'default'         	=> 'yes',
                    'options'     		=> array(
                        'yes'	=> __( 'Yes', 'woocommerce-gift-wrapper' ),
                        'no'	=> __( 'No', 'woocommerce-gift-wrapper' ),
                    ),
                    'autoload'          => false,
                );
                $settings[] = array(
                    'id'       			=> 'wcgwp_number',
                    'name'     			=> __( 'Allow more than one gift wrap product in cart?', 'woocommerce-gift-wrapper' ),
                    'desc_tip' 			=> __( 'If yes, customers can buy more than one gift wrapping product in one order.', 'woocommerce-gift-wrapper' ),
                    'type'     			=> 'select',
                    'default'         	=> 'no',
                    'options'     		=> array(
                        'yes'   => __( 'Yes', 'woocommerce-gift-wrapper' ),
                        'no'    => __( 'No', 'woocommerce-gift-wrapper' ),
                    ),
                    'autoload'          => false,
                );
            $settings[] = array(
                'type'  => 'sectionend',
            );
                    
            $settings[] = array( 
                'name' 				=> __( 'Advanced Options', 'woocommerce-gift-wrapper' ), 
                'type' 				=> 'title', 

            ); 
                
                 $settings[] = array(
                    'id'       			=> 'wcgwp_delete_all',
                    'name'     			=> __( 'Leave No Trace', 'woocommerce-gift-wrapper' ),
                    'type'     			=> 'checkbox',
                    'default'         	=> 'no',
                    'desc'     			=> __( 'Delete all Gift Wrapper settings upon plugin uninstall', 'woocommerce-gift-wrapper' ),
                    'desc_tip'          => __( 'If you plan on deleting this plugin and not coming back, and want to keep your Wordpress database tables tidy, check this box, save settings, then delete the plugin.', 'woocommerce-gift-wrapper' ),
                    'autoload'          => false,
                );
            $settings[] = array(
                'type' => 'sectionend',
            );
    
            $settings[] = array( 
                'id' 				=> 'wcgiftwrapper',
                'name' 				=> __( 'Thank you!', 'woocommerce-gift-wrapper' ), 
                'type' 				=> 'title', 
                'desc' 				=> '<div style="background:#fff;border:1px solid #e0c33f;padding-bottom:1em;padding-left:1em;padding-right:1em">
                                      <img src="' . plugins_url( "/assets/img/gift-wrapper-author.jpg", __DIR__ ) . '" alt="little package gravatar" style="float:right;height:160px;margin-bottom:1em;margin-left:1em;margin-top:1em;width:160px" />                                         
                                      <p style="font-size:1.125em">' . __( 'Hello. I\'m Caroline. I have volunteered to create and maintain this helpful and free plugin for you since October 2014.', 'woocommerce-gift-wrapper' ) . '<br />'
                                    . sprintf( wp_kses( __( 'If I have helped you, please stoke this plugin\'s dying fire by <a href="%s" target="_blank" rel="noopener">leaving a friendly review</a> and/or <a href="%s" target="_blank" rel="noopener">making a small donation</a>.', 'woocommerce-gift-wrapper' ), array( 'a' => array( 'href' => array() ) ) ), 'https://wordpress.org/support/plugin/woocommerce-gift-wrapper/reviews/?filter=5', 'https://www.buymeacoffee.com/littlepackage' ) . '</p>'
                                    . '<p>' . sprintf( wp_kses( __( 'Questions? Read the <a href="%s" target="_blank">Gift Wrapper FAQ</a>. Need further help? <a href="%s" target="_blank" rel="noopener">Use the Wordpress support forums for free plugin support</a>.' . '<br />'
                                    . 'Please include as many details as possible when requesting help.', 'woocommerce-gift-wrapper' ), array( 'a' => array( 'href' => array() ) ) ), 'https://wordpress.org/plugins/woocommerce-gift-wrapper/#faq', 'https://wordpress.org/support/plugin/woocommerce-gift-wrapper/' ) . '</p>'
                                    . '<p>' . __( 'Need more gift wrapping options, like per-product gift wrap, line-item gift wrap in the cart, more built-in styles, and easy string translations?', 'woocommerce-gift-wrapper' ) . '<br />' . sprintf( wp_kses( __( 'Check out the <a href="%s" target="_blank" rel="noopener">PLUS version of WooCommerce Gift Wrapper</a> by <strong>Little Package</strong>! (not sold at woocommerce.com)', 'woocommerce-gift-wrapper' ), array( 'a' => array( 'href' => array() ) ) ), 'https://web.little-package.com/downloads/woocommerce-gift-wrapper' )
                                    . '</p></div>'
            );
        
            $settings[] = array(
                'type' => 'sectionend',
                'id'    => 'wcgwp_settings_end',

            );
            
        }
        return $settings;
		
	}

}
endif;