<?php

if ( ! defined( 'WP_UNINSTALL_PLUGIN' ) ) { // If uninstall not called from WordPress exit
	exit();
}

/**
 * Manages WooCommerce Gift Wrapper uninstallation
 * The goal is to remove ALL WooCommerce Gift Wrapper related data in db
 *
 * @since 2.2
 */
class Gift_Uninstaller {

	/**
	 * Constructor: manages uninstall for multisite
	 *
	*/
	function __construct() {
		global $wpdb;

		// Check if it is a multisite uninstall - if so, run the uninstall function for each blog id
		if ( is_multisite() ) {
			foreach ( $wpdb->get_col( "SELECT blog_id FROM $wpdb->blogs" ) as $blog_id ) {
				switch_to_blog( $blog_id );
				$this->uninstall();
			}
			restore_current_blog();
		}
		else {
			$this->uninstall();
		}
	}

	/**
	 * Removes ALL plugin data only when the 'wcgwp_delete_all' option is active
	 *
	*/
	function uninstall() {
	
		if ( get_option( 'wcgwp_delete_all' ) !== 'yes' ) {
			return;
		}

        foreach ( array(
            'wcgwp_bootstrap_off',
            'wcgwp_category_id',
            'wcgwp_details',
            'wcgwp_display',
            'wcgwp_link',
            'wcgwp_number',
            'wcgwp_modal',
            'wcgwp_show_thumb',
            'wcgwp_textarea_limit',
            'wcgwp_donate_dismiss',
            'wcgwp_donate_dismiss_4-3',
            'wcgwp_donate_dismiss_11-16',
            'wcgwp_donate_dismiss_03-21',
            'wcgwp_version',
            'wcgwp_delete_all',
        ) as $option) {
                delete_option( $option );
        }
	}
}		
new Gift_Uninstaller();