<?php
/*
 * Plugin Name: Woocommerce Gift Wrapper
 * Plugin URI: https://web.little-package.com/downloads/woocommerce-gift-wrapper-plus/
 * Description: This plugin shows gift wrap options on the WooCommerce cart and/or checkout page, and adds gift wrapping to the order
 * Version: 4.4.7
 * WC requires at least: 3.0
 * WC tested up to: 5.4
 * Author: Little Package
 * Author URI: https://web.little-package.com
 * Donate link: https://paypal.me/littlepackage
 * Text Domain: woocommerce-gift-wrapper
 * Domain Path: /lang
 * 
 * Woocommerce Gift Wrapper
 * Copyright: (c) 2014-2021 Little Package
 *
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 *
 * This plugin is free. If you have problems with it, please be
 * nice and contact me for help before leaving negative feedback. 
 * Together we can make Wordpress better. Thank you.
 *
 * Wordpress developers need your support & encouragement! 
 * If you have found this plugin useful, 
 * and especially if you benefit commercially from it, 
 * please donate a few dollars to support my work & this plugin's future:
 * 
 * https://www.ko-fi.com/littlepackage
 * 
 * I understand you have a budget and might not be able to afford to buy the developer (me) a coffee in thanks. 
 * Maybe you can leave a positive review?
 * 
 * https://wordpress.org/support/plugin/woocommerce-gift-wrapper/reviews
 *
 * Thank you!
 * 
 * @todo remove gift wrap if cart adjusted and only virtual product left
 *
 */
defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'WC_Gift_Wrapper' ) ) :

    if ( ! defined( 'WCGW_PLUGIN_DIR' ) ) {
        define( 'WCGW_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
    }
    if ( ! defined( 'WCGW_PLUGIN_BASE_FILE' ) ) {
        define( 'WCGW_PLUGIN_BASE_FILE', plugin_basename(__FILE__) );
    }            
    if ( ! defined( 'WCGW_VERSION' ) ) {
        define( 'WCGW_VERSION', '4.4.7' );
    }
    
    class WC_Gift_Wrapper {
    
	    /**
	     * Single instance of the WC_Gift_Wrapper class
	     *
	     * @var WC_Gift_Wrapper
	    */
	    protected static $_instance = null;	    

        /**
	     * Wrapping instance.
	     *
	     * @var WCGW_Wrapping
	    */
	    public $wrapping = null;
	    	    
        public static function get_instance() {

            if ( ! isset( self::$_instance ) && ! ( self::$_instance instanceof WC_Gift_Wrapper ) ) {
                self::$_instance = new WC_Gift_Wrapper;
            }
            return self::$_instance;

        }

        /**
         * Constructor
        */
        public function __construct() {

            // let's deactivate Plus version of plugin if active
            register_activation_hook( __FILE__,             array( $this, 'activation_hook' ) );

            // Autoloader
            require_once WCGW_PLUGIN_DIR . '/autoloader.php';
            new WCGW_Autoloader();
            
            add_action( 'plugins_loaded',                   array( $this, 'plugins_loaded' ) );
            
            add_action( 'wp_enqueue_scripts',               array( $this, 'wp_enqueue_scripts' ), 99 );

        }

        public function __clone() {
            /* Cloning instances of the class is forbidden */
            _doing_it_wrong( __FUNCTION__, __( 'Cheatin&#8217; uh?', 'woocommerce-gift-wrapper' ), WCGW_VERSION );
        }

        public function __wakeup() {
            /* Unserializing instances of the class is forbidden */
            _doing_it_wrong( __FUNCTION__, __( 'Cheatin&#8217; uh?', 'woocommerce-gift-wrapper' ), WCGW_VERSION );
        }      
        
        /**
         * Deactivate the free version of WaterWoo if active
         * 
         * @return void
        */
        public function activation_hook() {

            if ( is_plugin_active( 'woocommerce-gift-wrapper-plus/woocommerce-gift-wrapper-plus.php' ) ) {
                deactivate_plugins( 'woocommerce-gift-wrapper-plus/woocommerce-gift-wrapper-plus.php' );
            }

        }

        /**
         * Load the localization 
         *
         * @return void
        */
        public function plugins_loaded() {

			$locale = determine_locale();
			$locale = apply_filters( 'plugin_locale', $locale, 'woocommerce-gift-wrapper' );

			unload_textdomain( 'woocommerce-gift-wrapper' );
			load_textdomain( 'woocommerce-gift-wrapper', WP_LANG_DIR . '/woocommerce-gift-wrapper/woocommerce-gift-wrapper-' . $locale . '.mo' );
            load_plugin_textdomain( 'woocommerce-gift-wrapper', false, dirname( plugin_basename( __FILE__ ) ) . '/lang' );	
    
            $this->update_db();

            if ( is_admin() ) {
                new WCGW_Admin_Notices();
                new WCGW_Settings();
            }
            
            $this->wrapping = new WCGW_Wrapping();
 
        }

        /**
         * Update Woo order item meta in version 4.0.3
         *
         * @return void
         * @since 4.0.3
        */
        public function update_db() {

            if ( get_option( 'wcgwp_version' ) === FALSE && get_option( 'giftwrap_category_id' ) ) {
                global $wpdb;
                $old = 'gift_wrap_note';
                $new = 'wcgwp_note';
                $wpdb->query( $wpdb->prepare(
                    "UPDATE {$wpdb->prefix}woocommerce_order_itemmeta SET meta_key = REPLACE( meta_key, %s, %s )", $old, $new
                ) );
            }

            $just_upgraded = FALSE;
            $version = preg_replace( '/[^0-9.].*/', '', get_option( 'wcgwp_version', '0.1' ) );            

            if ( version_compare( $version, '4.2.2', '<' ) ) {
                $just_upgraded = TRUE; // there has just been an upgrade to >= 4.2.2!
            }     
            
	        if ( $just_upgraded ) { 
	        
                $options = array( 
                    'giftwrap_bootstrap_off'        => 'wcgwp_bootstrap_off',
                    'giftwrap_category_id'          => 'wcgwp_category_id',
                    'giftwrap_details'              => 'wcgwp_details',
                    'giftwrap_display'              => 'wcgwp_display',
                    'giftwrap_link'                 => 'wcgwp_link',
                    'giftwrap_modal'                => 'wcgwp_modal',
                    'giftwrap_number'               => 'wcgwp_number',
                    'giftwrap_show_thumb'           => 'wcgwp_show_thumb',
                    'giftwrap_textarea_limit'       => 'wcgwp_textarea_limit',
                );
                
                foreach( $options as $old => $new ) {
                    if ( get_option( $old ) ) {
                        update_option( $new, get_option( $old ) );
                        delete_option( $old );
                    }
                }
                
                // clean up unused options in the DB
                $disused = array(
                    'giftwrap_button',
                    'giftwrap_header',
                    'giftwrap_text_label',
                );
                
                foreach( $disused as $option ) {
                    delete_option( $option );
                }
                 
                update_option( 'wcgwp_version', WCGW_VERSION, 'no' ); 

            }

        }

        /**
         * Enqueue scripts
         *
         * @return void
        */
        public function wp_enqueue_scripts() {

            if ( ! is_cart() && ! is_checkout() ) return;
        
            if ( get_option( 'wcgwp_modal', 'yes' ) == 'yes' ) { // modal
            
                wp_register_style( 'wcgiftwrap-modal-css', plugins_url( '/assets/css/wcgiftwrap_modal.css', __FILE__ ), array(), null );
                wp_enqueue_style( 'wcgiftwrap-modal-css' );
                
                if ( WCGW_Admin_Notices::check_template_outdated( array( 'wcgwp/modal.php' ) ) ) { // modal.php template is outdated
                    if ( get_option( 'wcgwp_bootstrap_off', 'no'  ) == 'no' ) {
                        wp_register_script( 'wcgwp-bootstrap', plugins_url( 'assets/js/bootstrap/wcgwp-bootstrap.min.js', __FILE__ ), 'jquery', null, TRUE );	
                        wp_enqueue_script( 'wcgwp-bootstrap' );	
                    }
                } else {
                    wp_register_script( 'wcgwp-modal', plugins_url( 'assets/js/modal-vanilla/modal.min.js', __FILE__ ), array(), null, TRUE );	
                    wp_enqueue_script( 'wcgwp-modal' );	
                    wp_register_script( 'wcgwp-modal-cart-checkout', plugins_url( 'assets/js/wcgwp-modal-cart-checkout.min.js', __FILE__ ), array( 'wcgwp-modal' ), null, TRUE );	
                    wp_enqueue_script( 'wcgwp-modal-cart-checkout' );
                }
                
            } else { // slideToggle
            
                if ( is_cart() && ! WCGW_Admin_Notices::check_template_outdated( array( 'wcgwp/cart-slideout-js.php' ) ) ||
                    is_checkout() && ! WCGW_Admin_Notices::check_template_outdated( array( 'wcgwp/checkout-slideout-js.php' ) ) ) {
                    wp_register_script( 'wcgwp-slide-cart-checkout', plugins_url( 'assets/js/wcgwp-slide-cart-checkout.js', __FILE__ ), array( 'jquery' ), null, TRUE );	
                    wp_enqueue_script( 'wcgwp-slide-cart-checkout' );
                }
                
                wp_register_style( 'wcgiftwrap-css', plugins_url( '/assets/css/wcgiftwrap.css', __FILE__ ), array(), null );        
                wp_enqueue_style( 'wcgiftwrap-css' );

            }

        }

    }  // End class WC_Gift_Wrapping

endif;

function WC_Gift_Wrap() {
    return WC_Gift_Wrapper::get_instance();
}
WC_Gift_Wrap();
// That's a wrap!